@@ -106,6 +106,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/aboutdialog.h>
 #include <gtkmm/accelerator.h>
 #include <gtkmm/accelkey.h>
+#include <gtkmm/accessibletext.h>
 #include <gtkmm/actionable.h>
 #include <gtkmm/actionbar.h>
 #include <gtkmm/adjustment.h>
@@ -172,6 +173,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/eventcontroller.h>
 #include <gtkmm/eventcontrollerfocus.h>
 #include <gtkmm/eventcontrollerkey.h>
+#include <gtkmm/eventcontrollerlegacy.h>
 #include <gtkmm/eventcontrollermotion.h>
 #include <gtkmm/eventcontrollerscroll.h>
 #include <gtkmm/filechooser.h>
@@ -203,6 +205,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/gestureswipe.h>
 #include <gtkmm/gesturezoom.h>
 #include <gtkmm/glarea.h>
+#include <gtkmm/graphicsoffload.h>
 #include <gtkmm/grid.h>
 #include <gtkmm/gridlayout.h>
 #include <gtkmm/gridlayoutchild.h>
@@ -250,6 +253,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/popovermenu.h>
 #include <gtkmm/popovermenubar.h>
 #include <gtkmm/printcontext.h>
+#include <gtkmm/printdialog.h>
 #ifndef G_OS_WIN32
 # include <gtkmm/printer.h>
 # include <gtkmm/printjob.h>
@@ -271,6 +275,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/scrolledwindow.h>
 #include <gtkmm/searchbar.h>
 #include <gtkmm/searchentry.h>
+#include <gtkmm/searchentry2.h>
 #include <gtkmm/separator.h>
 #include <gtkmm/sectionmodel.h>
 #include <gtkmm/selectionfiltermodel.h>
